pub fn plan(
desired: &[Object],
observed: &ObservedState,
state: &StateStore,
schema: &Schema,
allow_delete: bool,
) -> PlanExpand description
build a deterministic plan from desired and observed state.
pub fn plan(
desired: &[Object],
observed: &ObservedState,
state: &StateStore,
schema: &Schema,
allow_delete: bool,
) -> Planbuild a deterministic plan from desired and observed state.